***********************************************
* This SAS file provides code with which      *
* to replicate the material provided in the   *
* chapters                                    *
***********************************************;

/* This section provides codes for Chapter 5 */

/* 
1. This following code imports and shows some data management steps with the GSS 2014 data that 
include a question about attitudes toward gun laws The steps include (a) recode the variable 
gunlaw to 0,1, (b) recode the missing data, (c) assign new names and labels to the variables
                                     
2. Creation date: 20 Jan 2016             
3. Last updated: 20 Jan 2016  
4. Creator: Penelope, University of Ithica 
5. Created for SPSS version 21 
*/

/* assign a library name where the data files reside 
/* this is useful for saving SAS files to local directories */
libname john "[pathname]" ;

/* import the data */
proc import datafile="[pathname]\GSS2014.txt" 
 out=gss2014data replace ;
 delimiter=',';
 getnames=yes;
run;

/* rename and label the variables */
data gss2014data (rename=(GUNLAW = GunPermit EDUC = education SEX = female AGE = age));
 set gss2014data;
 label 
  GunPermit = "Favor police permits for guns"
  education = "Years of formal education"
  female = "Sex of respondent"
  age = "Age of respondent" ;
run;

/* recode the variables */
data gss2014data;
 set gss2014data;
 if (GunPermit=0) or (GunPermit>7) then GunPermit=.;
 if (GunPermit=2) then GunPermit=0 ;
 if (education>96) then education=.;
 if (female=0) then female=.;
 if (female=1) then female=0;
 if (female=2) then female=1;
 if (age=0) or (age>97) then age=.;
run;

/* assign value labels */
proc format;
 value gun 0 = "oppose"
           1 = "favor";
 value fem 
  0 = "male" 
  1 = "female";  
run;

/* check the results */
proc freq data=gss2014data;
 format GunPermit gun.
        female fem.;
 tables GunPermit female;
run; 

proc univariate data=gss2014data;
 var education age ;
run;

/*create a constant for the boxplot command */
data gss2014data; 
 set gss2014data;
 const=1;
run;

proc boxplot data=gss2014data;
 plot age*const;
run;

proc gplot data=gss2014data;
 plot education*age;
run;

proc freq data=gss2014data;
 where age>19 and age<51;
 tables GunPermit female;
run; 

proc surveyselect data=gss2014data method=srs rep=1 sampsize=847
     seed=76543 out=subgss2014 ;
 id _all_ ;
run;

proc freq data=subgss2014;
 tables GunPermit female;
run; 

* means ; 
proc means data=gss2014data mean;
 class GunPermit;
 var education;
run;

* boxplots ;
proc boxplots data=gss2014data;
 plot education*GunPermit;
run; 


*********************************************************************
* This section produces the information for the tables in Chapter 9 *
* and provides code for several of the graphics in Chapter 10       *
*********************************************************************

/* Chapter 9 */ 

/* mean education by gun permits ;
proc means data=gss2014data mean;
 format GunPermit gun.;
 class GunPermit;
 var education;
run;

/* means by sex */
proc means data=gss2014data mean;
 format female fem. GunPermit gun.;
 class GunPermit female ;
 var education;
run;

/* recode education into categories */
data gss2014data;
 set gss2014data;
educCat = .;
 if (education >= 0) and (education < 12) then educCat=1;
 if (education = 12) then educCat=2;
 if (education > 12) and (education < 16) then educCat=3;
 if (education > 15) and (education < 21) then educCat=4; 
label educCat = "Education categorized";
run;

/* create value labels for education categories */
proc format;
 value edCat 1 = "Not HS graduate"
             2 = "High school graduate"
             3 = "Attended college"
             4 = "College graduate";  
run;

/* means favor gun permits by education categories */
proc means data=gss2014data mean;
 format educCat edCat. female fem. ;
 class educCat;
 var GunPermit;
run;

/* means favor gun permits by education categories */
proc means data=gss2014data mean;
 format educCat edCat. female fem.;
 class educCat female;
 var GunPermit;
run;


/* Chapter 10 */

/* Request journal style output - grayscale */
ods graphics on / reset=index;
ods listing close ;
ods html style=Journal; 

/* Figure 10.6 */
/* Pie chart - education categories */
Title 'Figure 10.6. Pie chart example: Education categories';
proc gchart data=gss2014data;
 format educCat edCat.;
 pie educCat / discrete value=inside clockwise descending;
run;


/* Figure 10.8 */
/* Horizontal bar chart - education categories */
Title 'Figure 10.8. Horizontal bar chart of education categories';
axis2 label=('Percent in each education category');
proc gchart data=gss2014data;
 format educCat edCat.;
 hbar educCat / discrete descending type=pct raxis=axis2 outside=pct;
run;


/* Figure 10.9 */ 
/* Dot plot - education categories */
Title 'Figure 10.9. Dot plot of education categories';
proc sgplot data=gss2014data;
 format educCat edCat.;
 dot educCat / categoryorder=respdesc stat=pct markerattrs=(symbol=circlefilled);
 xaxis label="Percent in each education category" min=0 ;
 yaxis label=" ";
run; 


/* Figure 10.11 */
/* Dot plot - proportion favoring gun permits */
Title 'Figure 10.11. Proportion in favor of gun permits, by education';
proc sgplot data=gss2014data;
 format educCat edCat.;
 dot educCat / categoryorder=respdesc stat=mean response=GunPermit markerattrs=(symbol=circlefilled) ;
 xaxis label="Proportion favoring gun permits" min=0;
 yaxis label=" ";
run; 


/* Figure 10.12 */
/* Dot plot by education and sex */
proc sgpanel data=gss2014data;
 format educCat edCat. female fem.;
 title 'Figure 10.12. Proportion in favor of gun permits, by education and sex';
 panelby female / novarname columns=1;
 dot educCat / categoryorder=respdesc stat=mean response=GunPermit markerattrs=(symbol=circlefilled);
 colaxis label="Proportion favoring gun permits" min=0;
 rowaxis label="level of education";
run;


/* Figure 10.13 */
/* Line graph of favor gun permits by education categories */ 
Title 'Figure 10.13. Proportion in favor of gun permits, by education and sex';
proc sgplot data=gss2014data noautolegend;
 format educCat edCat. female fem.;
 vline educCat / stat=mean response=GunPermit group=female;
 xaxis label="Proportion favoring gun permits";
 yaxis label="Proportion favoring gun permits" min=0.5 max=0.9;
run; 


/* Figure 10.14 */
/* Line graph of favoring gun permits by continuous education */
Title 'Figure 10.14. Linear fit of association between favoring gun permits and education, by sex';
proc sgplot data=gss2014data noautolegend;
 format female fem.;
 reg x=education y=GunPermit / group=female;
 xaxis label="Years of education";
 yaxis label="Proportion favoring gun permits" min=0.5 max=0.9;
run;


/* Figure 10.14 */
/* Line graph of favoring gun permits by continuous education */
Title 'Figure 10.14. Lowess fit of association between favoring gun permits and education, by sex';
proc sgplot data=gss2014data noautolegend;
 format female fem.;
 loess x=education y=GunPermit / group=female;
 xaxis label="Years of education";
 yaxis label="Proportion favoring gun permits" min=0.5 max=0.9;
run;

ods html close;
ods listing;
ods listing close; 


/* Import violent crime trend data */
proc import datafile="[pathname]\ViolentCrimeTrends.csv" 
 out=violentcrimetrends replace;
 delimiter=',';
 getnames=yes;
run;

data violentcrimetrends;
 set violentcrimetrends;
run;

/* Request journal style output */

ods graphics on / reset=index;
ods listing close ;
ods html style=Journal; 

/* Figure 10.15 */
/* Line graph of trends in violent crimes in three states   */
Title 'Figure 10.15. Violent crime rates, 1990-2014';
proc sgplot data=violentcrimetrends noautolegend;
 where (fipscode=6 or fipscode=21 or fipscode=56);
 vline Year / response=ViolentCrimeRate group=fipscode;
 xaxis label="Year";
 xaxis values=(1990 to 2012 by 5);
 yaxis label="Violent crimes per 100,000 population";
run;
 
ods html close;
ods listing;
ods listing close; 


/* Import endangered species data */
proc import datafile="[pathname]\EndangeredSpecies.csv" 
 out=endangeredspecies replace ;
 delimiter=',';
 getnames=yes;
run;


/* Label the variables */
data endangeredspecies;
 set endangeredspecies;
 label 
  Nation = "Name of Nation"
  NationNumber = "Nation code"
  EnergyConsumption = "Energy consumption per capita"
  CO2Emissions = "CO2 emissions per capita"
  EndangerRate = "Rate of endangered species"
  IncomeLevel = "Income level, 0=low, 1=high"
  GDP = "Gross domestic product per capita" ;
run;
*/

/* create value labels for the nations based on NationNumber */
proc format;
 value nationabbrev 
   1="AO" 2="BD" 3="BZ" 4="BJ" 5="BT" 6="BO" 7="BW" 
   8="BF" 9="BI" 10="CM" 11="CF" 12="TD" 13="CH"
  14="CO" 15="CG" 16="CR" 17="CI" 18="DO" 19="EC" 
  20="SV" 21="CQ" 22="ET" 23="FJ" 24="GA" 25="GM" 
  26="GH" 27="GT" 28="GN" 29="GW" 30="GY" 31="HT" 
  32="HN" 33="IS" 34="JM" 35="LA" 36="LR"
  37="MG" 38="MW" 39="ML" 40="MR" 41="MU" 42="MN" 
  43="MA" 44="MZ" 45="MM" 46="NP" 47="NI" 48="NE"  
  49="OM" 50="PK" 51="PA" 52="PG" 53="PY" 54="RW" 
  55="SN" 56="SL" 57="SB" 58="SO" 59="LK" 60="SD"
  61="SR" 62="SZ" 63="SY" 64="TZ" 65="TG" 66="TT" 
  67="TN" 68="UG" 69="VN" 70="CD" 71="ZM" 72="ZW" ;
run;
						  

/* Request journal style output */
ods graphics on / reset=index;
ods listing close ;
ods html style=Journal; 

/* Figure 10.17 */
/* Scatterplot of CO2 emissions and endangered species */
Title 'Figure 10.17. CO2 Emissions and Endangered Species, by Country';
footnote j=l "Source: World Bank & IUCN Red List, 2006."; 
proc sgplot data=endangeredspecies noautolegend;
 format NationNumber nationabbrev.;
 scatter x=CO2Emissions y=EndangerRate;
 xaxis label="CO2 emissions per capita" max=12;
 yaxis label="Rate of endangered species";
run;

 
/* Figure 10.18 */
/* Scatterplot of CO2 emissions and endangered species with nation abbreviations as markers */
Title 'Figure 10.18. CO2 Emissions and Endangered Species, by Country';
footnote j=l "Source: World Bank & IUCN Red List, 2006."; 
proc sgplot data=endangeredspecies noautolegend;
 format NationNumber nationabbrev.;
 scatter x=CO2Emissions y=EndangerRate / markerchar=NationNumber;
 xaxis label="CO2 emissions per capita" max=12;
 yaxis label="Rate of endangered species";
run;
 

/* Figure 10.19 */
/* Scatterplot of CO2 emissions and endangered species */
/* with line plot using a linear fit  */
Title 'Figure 10.19. CO2 Emissions and Endangered Species, by Country';
footnote j=l "Source: World Bank & IUCN Red List, 2006."; 
proc sgplot data=endangeredspecies noautolegend;
 format NationNumber nationabbrev.;
 scatter x=CO2Emissions y=EndangerRate ;
 reg x=CO2Emissions y=EndangerRate ;
 xaxis label="CO2 emissions per capita" max=12;
 yaxis label="Rate of endangered species";
run;


/* Figure 10.20 */
/* Scatterplot of CO2 emissions and endangered species by income level */ 
/* First, create a data set with the markers to use in the scatterplot */
data myattrib;
 input id $ value markersymbol $;
 datalines;
  myid 0 Triangle
  myid 1 Circle
;
run;

/* Second, request the scatterplot with the particular markers */
Title 'Figure 10.20. CO2 Emissions and Endangered Species, by Country Income Level';
footnote j=l "Source: World Bank & IUCN Red List, 2006."; 
proc sgplot data=endangeredspecies dattrmap=myattrib noautolegend;
 scatter x=CO2Emissions y=EndangerRate / group=IncomeLevel markerattrs=(size=8pt) attrid=myid;
 xaxis label="CO2 emissions per capita" max=12;
 yaxis label="Rate of endangered species";
run;


/* Figure 10.21 */
/* Scatterplot of CO2 emissions and endangered species by income level */ 
Title 'Figure 10.21. CO2 Emissions and Endangered Species, by Country Income Level';
footnote j=l "Source: World Bank & IUCN Red List, 2006."; 
proc sgplot data=endangeredspecies dattrmap=myattrib noautolegend;
 scatter x=CO2Emissions y=EndangerRate / group=IncomeLevel markerattrs=(size=8pt) attrid=myid;
 reg x=CO2Emissions y=EndangerRate / group=IncomeLevel nomarkers ;
 xaxis label="CO2 emissions per capita" max=12;
 yaxis label="Rate of endangered species";
run;

ods html close;
ods listing;
ods listing close; 
