***********************************************
* This Stata do file provides code with which *
* to replicate the material provided in the   *
* chapters                                    *
***********************************************

/* Chapter 5 */

/* 
 1. This code is designed to import and show some
    data management steps with the GSS 2014 data
    that include a question about attitudes toward
    gun laws The steps include    
    (a) recode the variable gunlaw to 0,1
    (b) recode the missing data 
    (c) assign new names and labels to the variables
 2. Creation date: 20 Jan 2016            
 3. Last updated:  20 Jan 2016 
 4. Creator: Penelope, University of Ithica 
 5. Created for Stata, version 14
 */

/* import GSS 2014 data */
import delimited [pathname]\GSS2014.txt

/* rename the variables */
rename gunlaw GunPermit
rename educ education
rename sex female

/* label the variables */
label variable GunPermit "Favor police permits for guns"
label variable education "Years of formal education"
label variable female "Sex of respondent"
label variable age "Age of respondent"

/* recode the variables */
recode GunPermit (1=1)(2=0)(else=.)
recode education (97/99=.)
recode female (1=0)(2=1) (else=.)
recode age (0=.)(98/99=.)

/* assign value labels */
label define gun 0 "oppose" 1 "support"
label values GunPermit gun
label define fem 0 "male" 1 "female"
label values female fem

/* check the results */
tab1 GunPermit female
summarize education age, detail

graph box education, by(GunPermit)


*********************************************************************
* This section produces the information for the tables in Chapter 9 *
* and provides code for several of the graphics in Chapter 10       *
*********************************************************************

/* Chapter 9 */ 

/* Table of mean education by gun permit and sex */
mean education, over(GunPermit)
mean education, over(GunPermit female)

/* Create and label categorical education variable */
recode education (0/11=1)(12=2)(13/15=3)(16/20=4), gen(educCat)
label variable educCat "Education categorized"
label define educCatlab 1 "Not HS graduate" 2 "High school graduate" 3 ///
                          "Attended college" 4 "College graduate"
label values educCat educCatlab

/* Table of mean favor of gun permits by education and sex */
mean GunPermit, over(educCat)
mean GunPermit, over(educCat female)


/* Chapter 10 */

/* Figure 10.6 */
/* Pie chart - education categories */
graph pie, over(educCat) sort descending angle(90) plabel(_all name)            ///
 intensity(inten70) title(Figure 10.6. Pie chart example: Education categories) ///
 legend(off) scheme(s1mono)

/* Figure 10.8 */
/* Horizontal bar chart - education categories */
graph hbar, over(educCat, sort(1) descending label(labcolor(black))) ///
 ytitle("Percent in each education category")                        ///
 ylabel(, nogrid tposition(inside))                                  ///
 title("Figure 10.8. Horizontal bar chart of education categories",  ///
 size(medlarge)) scheme(s2mono) intensity(inten70)

/* Figure 10.9 */ 
/* Dot plot - education categories */
preserve
collapse (count) caseid, by(educCat)
gen number = (caseid/2537)*100
graph dot number, over(educCat, sort(1) descending)      ///
 ytitle("Percent in each education category")            ///
 title("Figure 10.9. Dot plot of education categories")  ///
 ylabel(, nogrid tposition(inside))                      ///
 aspectratio(0.75) marker(1, msymbol(O) mcolor(black)    ///
 mlwidth(medthick) msize(medlarge)) scheme(s2mono) 
restore
 
/* Figure 10.11 */
/* Dot plot - proportion favoring gun permits */
graph dot GunPermit, over(educCat, sort(1) descending)     ///
 ytitle("Proportion favoring gun permits")                 ///
 title("Figure 10.11. Proportion in favor of gun permits") ///
 subtitle("by level of education") aspectratio(0.75)       ///
 ylabel(, nogrid tposition(inside))                        ///
 marker(1, msymbol(O) mcolor(black) mlwidth(medthick)      ///
 msize(medlarge)) scheme(s2mono)                           ///
 note("Source: General Social Survey, 2014.")

/* Dot plot with 95% CIs */
qui anova GunPermit educCat
qui margins educCat
marginsplot, horizontal recast(scatter)                       ///
 title("Figure 10.11a. Confidence intervals")                 ///
 xtitle("Proportion in favor of gun permits") ytitle("")      ///
 xlabel(0(0.2)0.8) plot1opts(msymbol(O) mcolor(black)         ///
 mlwidth(medthick) msize(medlarge)) 

/* Figure 10.12 */
/* Dot plot by education and sex */
/* Stack males and females */
graph dot GunPermit, over(educCat, sort(1) descending) over(female) ///
  ytitle("Proportion in favor of gun permits")                      ///
  title("Dot plot of proportion who favor gun permits")             ///
  subtitle("by level of education and sex")                         ///
  ylabel(, nogrid tposition(inside)) aspectratio(1)                 ///
  marker(1, msymbol(O) mcolor(black) mlwidth(medthick)              ///
  msize(medlarge)) scheme(s2mono)

/* Figure 10.12 */
/* Females and males by education */
graph dot GunPermit, over(female, sort(1) descending) over(educCat) ///
  ytitle("Proportion in favor of gun permits") aspectratio(1)       ///
  ylabel(, nogrid tposition(inside))                                ///
  marker(1, msymbol(O) mcolor(black) mlwidth(medthick)              ///
  msize(medlarge)) scheme(s2mono)

/* limit range of the y-axis on dotplot */
graph dot GunPermit, over(female, sort(1) descending) over(educCat) ///
  aspectratio(1) scheme(s2mono) exclude0 yscale(range(0.5(0.1)0.9)) ///
  ylabel(#6, nogrid tposition(inside)) marker(1, msymbol(O)         ///
  mcolor(black) mlwidth(medthick) msize(medlarge))
/* exclude0 resets scale to not include zero
   yscale uses the range from 0.5 to 0.9 in increments of 0.1
   ylabel specifies six with ticks to be used */

/* Figure 10.13 */
/* Line graph of favor gun permits by education categories */
preserve
collapse (count) caseid (mean) GunPermit, by(educCat female)
graph twoway line GunPermit educCat if female==0, xlabel(1 2 3 4, valuelabel) ///
      xtitle("") ytitle("Proportion favoring gun permits")                    ///
	  title("Figure 10.13. Proportion in favor of gun permits")               ///
	  subtitle("by education categories and sex") yscale(range(.5 .9))        ///
	  ylabel(#4,tposition(inside)) text(.72 3.5 "Males", place(c))            ///
	  lwidth(medthick) || line GunPermit educCat if female==1, legend(off)    ///
	  text(.81 3.5 "Females", place(c)) scheme(s1mono) aspectratio(0.7)       ///
	  lwidth(medthick) xlabel(,tposition(inside))                             ///
	  note("Source: General Social Survey, 2014.")
restore

/* Figure 10.14 */
/* Linear fit line of favoring gun permits by continuous education */
twoway lfit GunPermit education if female==0,                    ///
       ytitle("Proportion in favor of gun permits")              ///
	   xlabel(, tposition(inside)) lwidth(medthick)              ///
	   text(.68 17 "Males", place(c))                            ///
	   title("Figure 10.14. Proportion in favor of gun permits") ///
	   subtitle("by years of formal education and sex")          ///
	   yscale(range(.5 .9)) ylabel(#4,tposition(inside))         ///
       || lfit GunPermit education if female==1,                 ///
	   lwidth(medthick) text(.78 17 "Females", place(c))         ///
	   legend(off) scheme(s2mono)                                ///
	   note("Source: General Social Survey, 2014.")

/* Lowess smoother depiction of favoring gun permits by education */
twoway lowess GunPermit education if female==0 & education>0,     ///
       ytitle("Proportion in favor of gun permits")               ///
	   xlabel(, tposition(inside)) lwidth(medthick)               ///
	   text(.68 17 "Males", place(c)) yscale(range(.5 .9))        ///
	   title("Figure 10.14. Proportion in favor of gun permits")  ///
	   subtitle("by years of formal education and sex")           ///
	   ylabel(#4,tposition(inside))  ||                           ///
       lowess GunPermit education if female==1 & education>0,     ///
	   lwidth(medthick) text(.78 17 "Females", place(c))          ///
	   legend(off) scheme(s2mono)                                 ///
	   note("Source: General Social Survey, 2014.")
	   
/* Clear data from memory and load the state-level violent crime data set */
clear all

/* import data */
import delimited [pathname]\ViolentCrimeTrends.csv

/* Figure 10.15 */
/* Line graph of trends in violent crimes in three states   */
graph twoway line ViolentCrimeRate Year if fipscode==6,      ///
      ylabel(#4,tposition(inside)) lwidth(medthick)          ///
	  ytitle("Violent crimes per 100,000 population")        ///
	  text(550 2009 "California", place(c)) ||               ///
	  line ViolentCrimeRate Year if fipscode==21,            ///
	  lwidth(medthick) text(330 2009 "Kentucky", place(c))   ///
	  || line ViolentCrimeRate Year if fipscode==56,         ///
	  lwidth(medthick) lpattern(dash)                        ///
	  text(165 2009 "Wyoming", place(c)) legend(off)         ///
	  xlabel(,tposition(inside)) scheme(s1mono)              ///
	  title("Figure 10.15. Violent crime rates, 1990-2012,") ///
	  subtitle("California, Kentucky, and Wyoming")          ///
	  note("Source: FBI, Uniform Crime Reports, 1990-2012")

	  
/* Clear data from memory and load the endangered species data set */
clear all

/* import the Endangered Species data */
import delimited [pathname]\EndangeredSpecies.csv 

/* Label the variables and the country codes */
/* Create variables labels */
label variable Nation "Name of Nation"
label variable NationNumber "Nation code"
label variable EnergyConsumption "Energy consumption per capita"
label variable CO2Emissions "CO2 emissions per capita"
label variable EndangerRate "Rate of endangered species"
label variable IncomeLevel "Income level, 0=low, 1=high"
label variable GDP "Gross domestic product per capita"

/* create value labels for the nations based on NationNumber */
label drop nationabbrev

label define nationabbrev 1 "AO" 2 "BD" 3 "BZ" 4 "BJ" 5 "BT" 6 "BO" 7 "BW" ///
                          8 "BF" 9 "BI" 10 "CM" 11 "CF" 12 "TD" 13 "CH"    ///
						  14 "CO" 15 "CG" 16 "CR" 17 "CI" 18 "DO" 19 "EC"  ///
						  20 "SV" 21 "CQ" 22 "ET" 23 "FJ" 24 "GA" 25 "GM"  ///
						  26 "GH" 27 "GT" 28 "GN" 29 "GW" 30 "GY" 31 "HT"  ///
						  32 "HN" 33 "IS" 34 "JM" 35 "LA" 36 "LR" 37 "MG"  ///
						  38 "MW" 39 "ML" 40 "MR" 41 "MU" 42 "MN" 43 "MA"  ///
						  44 "MZ" 45 "MM" 46 "NP" 47 "NI" 48 "NE" 49 "OM"  ///
						  50 "PK" 51 "PA" 52 "PG" 53 "PY" 54 "RW" 55 "SN"  ///
						  56 "SL" 57 "SB" 58 "SO" 59 "LK" 60 "SD" 61 "SR"  ///
						  62 "SZ" 63 "SY" 64 "TZ" 65 "TG" 66 "TT" 67 "TN"  ///
						  68 "UG" 69 "VN" 70 "CD" 71 "ZM" 72 "ZW"
						  
label values NationNumber nationabbrev */

/* Figure 10.17 */
/* Scatterplot of CO2 emissions and endangered species */
twoway scatter EndangerRate CO2Emissions, msymbol(Oh) mcolor(black) ///
       msize(medlarge) xlabel(,tposition(inside))                   ///
	   ylabel(,nogrid tposition(inside))                            ///
	   title("Figure 10.17. CO2 Emissions & Endangered Species,")   ///
	   subtitle("by Country", size(large)) scheme(s1mono)           ///
	   note("Source: World Bank & IUCN Red List, 2006.")

/* Figure 10.18 */
/* Scatterplot of CO2 emissions and endangered species */
/* with nation abbreviation for markers */
twoway scatter EndangerRate CO2Emissions, mlabel(NationNumber)    ///
       mstyle(none) xlabel(,tposition(inside))                    ///
	   ylabel(,nogrid tposition(inside)) jitter(5)                ///
	   title("Figure 10.18. CO2 Emissions & Endangered Species,") ///
	   subtitle("by Country", size(large)) scheme(s1mono)         ///
	   note("Source: World Bank & IUCN Red List, 2006.")
	   
/* Figure 10.19 */
/* Scatterplot of CO2 emissions and endangered species */
/* with a linear fit line  */
twoway scatter EndangerRate CO2Emissions, msymbol(Oh) mcolor(black) ///
       msize(medlarge) xlabel(,tposition(inside))                   ///
	   ylabel(,nogrid tposition(inside))                            ///
	   title("Figure 10.19. CO2 Emissions & Endangered Species,")   ///
	   subtitle("by Country", size(large)) scheme(s1mono)           ///
	   note("Source: World Bank & IUCN Red List, 2006.")	||      ///
	   lfit EndangerRate CO2Emissions, lwidth(medthick)             ///
	   lcolor(black) ytitle("Rate of endangered species")           ///
	   legend(off)  

/* Figure 10.20 */
/* Scatterplot of CO2 emissions and endangered species by income level */
twoway scatter EndangerRate CO2Emissions if IncomeLevel==0,         ///
       msymbol(Oh) mcolor(black) msize(medlarge)                    ///
	   xlabel(,tposition(inside)) ylabel(,nogrid tposition(inside)) ///
	   title("Figure 10.20. CO2 Emissions & Endangered Species,")   ///
	   subtitle("by Country's Income Level", size(large))           ///
	   note("Source: World Bank & IUCN Red List, 2006.")	        ///
	   scheme(s1mono) ||                                            /// 
	   scatter EndangerRate CO2Emissions if IncomeLevel==1,         ///
	   msymbol(Th) mcolor(black) msize(medlarge) legend(off)    
	   
/* Figure 10.21 */
/* Scatterplot of CO2 emissions and endangered species by income level */
twoway scatter EndangerRate CO2Emissions if IncomeLevel==0,         ///
       msymbol(Oh) mcolor(black) msize(medlarge)                    ///
	   xlabel(,tposition(inside)) ylabel(,nogrid tposition(inside)) ///
	   title("Figure 10.21. CO2 Emissions & Endangered Species,")   ///
	   subtitle("by Country's Income Level", size(large))           ///
	   note("Source: World Bank & IUCN Red List, 2006.")	        ///
	   scheme(s1mono) ||                                            /// 
	   scatter EndangerRate CO2Emissions if IncomeLevel==1,         ///
	   msymbol(Th) mcolor(black) msize(medlarge) legend(off) ||     ///
	   lfit EndangerRate CO2Emissions if IncomeLevel==0,            ///
	   lwidth(medthick) lcolor(black)                               ///
	   ytitle("Rate of endangered species") legend(off) ||          /// 
	   lfit EndangerRate CO2Emissions if IncomeLevel==1,            ///
	   lwidth(medthick) lcolor(black) lpattern(dash)
	   
/* Figure 10.22 */
/* Contour plot of CO2 emissions and endangered species by income level */
twoway contour IncomeLevel EndangerRate CO2Emissions , levels(4)        ///
       scolor(white) ecolor(black) crule(intensity)                     ///
	   title("Figure 10.22. CO2 Emissions & Endangered Species")        ///
	   subtitle("by Country's Income Level", size(large))               ///
	   xlabel(,tposition(inside)) ylabel(,nogrid tposition(inside))     ///
	   note("Source: World Bank & IUCN Red List, 2006.") legend(off) || ///
	   scatter EndangerRate CO2Emissions if IncomeLevel==0,             ///
       msymbol(Oh) mcolor(white) msize(medlarge)   ||                   ///
	   scatter EndangerRate CO2Emissions if IncomeLevel==1,             ///
	   msymbol(Th) mcolor(white) msize(medlarge) legend(off)
	   

	   
